@@ -1,7 +1,7 @@
 /*
  * This file is part of nzbget. See <http://nzbget.net>.
  *
- * Copyright (C) 2012-2017 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -179,14 +179,14 @@ var History = (new function($)
 			var kind = hist.Kind;
 			hist.status = HistoryUI.buildStatusText(hist);
 			hist.name = hist.Name;
-			hist.size = kind === 'URL' ? '' : Util.formatSizeMB(hist.FileSizeMB);
+			hist.size = kind === 'URL' && hist.FileSizeLo == 0 && hist.FileSizeHi == 0 ? '' : Util.formatSizeMB(hist.FileSizeMB);
 			hist.sizemb = hist.FileSizeMB;
 			hist.sizegb = hist.FileSizeMB / 1024;
 			hist.time = Util.formatDateTime(hist.HistoryTime + UISettings.timeZoneCorrection*60*60);
 			hist.category = kind !== 'DUP' ? hist.Category : '';
 			hist.dupe = DownloadsUI.buildDupeText(hist.DupeKey, hist.DupeScore, hist.DupeMode);
-			var age_sec = kind === 'NZB' ? new Date().getTime() / 1000 - (hist.MinPostTime + UISettings.timeZoneCorrection*60*60) : 0;
-			hist.age = kind === 'NZB' ? Util.formatAge(hist.MinPostTime + UISettings.timeZoneCorrection*60*60) : '';
+			var age_sec = hist.MinPostTime > 0 ? new Date().getTime() / 1000 - (hist.MinPostTime + UISettings.timeZoneCorrection*60*60) : 0;
+			hist.age = hist.MinPostTime > 0 ? Util.formatAge(hist.MinPostTime + UISettings.timeZoneCorrection*60*60) : '';
 			hist.agem = Util.round0(age_sec / 60);
 			hist.ageh = Util.round0(age_sec / (60*60));
 			hist.aged = Util.round0(age_sec / (60*60*24));
@@ -654,7 +654,7 @@ var HistoryUI = (new function($)
 
 /*** HISTORY ACTION MENU *************************************************************************/
 
-var HistoryActionsMenu = (new function()
+var HistoryActionsMenu = (new function($)
 {
 	'use strict'
 
